@@ -5,7 +5,7 @@ import logging
 
 from pyagentx2.agent import Agent
 from pyagentx2.updater import Updater
-from pyagentx2.sethandler import SetHandler, GenErrException, NoAccessException, WrongTypeException, WrongLengthException, WrongEncodingException, WrongValueException, NoCreationException, InconsistentValueException, ResourceUnavailableException, NotWritableException, InconsistentNameException
+from pyagentx2.sethandler import SetHandler, GenErrException, NoAccessException, WrongTypeException, WrongLengthException, WrongEncodingException, WrongValueException, NoCreationException, InconsistentValueException, ResourceUnavailableException, NotWritableException, InconsistentNameException, CommitFailedException
 
 
 def setup_logging(debug=False):
